@@ -15,8 +15,9 @@ get_jspec.X13 <- function(x, ...){
   } else {
     jrspec <- .jcall("jdr/spec/x13/X13Spec", "Ljdr/spec/x13/X13Spec;", "of", "RSA0")
   }
-  jdictionary <- spec_regarima_X13_r2jd(spec,jrspec)
-  seasma <- specX11_r2jd(spec,jrspec, freq = frequency(x$final$series))
+  spec_regarima_X13_r2jd(spec,jrspec)
+  specX11_r2jd(spec,jrspec, freq = frequency(x$final$series))
+  spec_benchmarking_r2jd(spec, jrspec)
   jspec <- .jcall(jrspec, "Lec/satoolkit/x13/X13Specification;", "getCore")
   jspec
 }
@@ -24,8 +25,9 @@ get_jspec.X13 <- function(x, ...){
 get_jspec.TRAMO_SEATS <- function(x, ...){
   spec <- tramoseats_spec(x, ...)
   jrspec <- .jcall("jdr/spec/tramoseats/TramoSeatsSpec", "Ljdr/spec/tramoseats/TramoSeatsSpec;", "of", "RSA0")
-  jdictionary <- spec_TRAMO_r2jd(spec,jrspec)
-  spec_seats <- specSeats_r2jd(spec,jrspec)
+  spec_TRAMO_r2jd(spec,jrspec)
+  specSeats_r2jd(spec,jrspec)
+  spec_benchmarking_r2jd(spec, jrspec)
   jspec <- .jcall(jrspec, "Lec/satoolkit/tramoseats/TramoSeatsSpecification;", "getCore")
   jspec
 }
